
import React, { useEffect, useState, useRef } from "react";
import * as d3 from "d3";
import { nice } from "d3";

const dateFormatOptions = {month: "long", year: "numeric"}

export default function Graph2() {
    const Y_MAX = 1000;
    const X_MAX = 1000;

    const [xTicks, setXTicks] = useState<{ value: Date; xOffset: number; }[]>([])
    const [yTicks, setYTicks] = useState<{value: number, yOffset: number}[]>([])
    const [data,setData] = useState<{ date: Date; xOffset: number; amount: number, yOffset: number}[]>([])

    useEffect(() => {
        const items = [{ date: "2017-01-01", amount: 50 }, { date: "2017-06-01", amount: 30 }, { date: "2018-01-01", amount: 70 }]

        const xScale = d3.scaleTime()
            .domain([new Date(items[0].date), new Date(items[2].date)])
            .nice()
            .range([0, X_MAX])
        
        let sortedItems = items.sort((a,b) => {return a.amount - b.amount})
        
        const yScale = d3.scaleLinear()
            .domain([sortedItems[sortedItems.length - 1].amount, 0])
            .nice()
            .range([0, Y_MAX])
        
        setXTicks(xScale.ticks()
            .map(value => ({
                value,
                xOffset: xScale(value)
            })))
        setYTicks(yScale.ticks()
            .map(value => ({
                value,
                yOffset: yScale(value)
            })))
        setData(items.map(item => {
            let date = new Date(item.date)
            let dateString = new Intl.DateTimeFormat('fr-FR', {month: "long", year: "numeric"}).format(date)
            return {date: new Date(item.date), xOffset: xScale(new Date(item.date)), amount: item.amount, yOffset: yScale(item.amount)}
        }));
    },[])

    return (
        <div>
            <svg id="graph"
                width="100%"
                height={Y_MAX + 50}
            >
                <path
                    d={`M 9.5 0.5 H ${Y_MAX}`}
                    stroke="currentColor"
                />
                <AxisX ticks={xTicks} transform={`translate(${50}, ${500})`}/>
                {/* {yTicks.map(({ value, yOffset }) => (
                    <g
                        key={value}
                        transform={`translate(${20}, ${yOffset})`}
                    >
                        <line
                            y2="50"
                            stroke="currentColor"
                        />
                        <text
                            key={value}
                            style={{
                                fontSize: "10px",
                                textAnchor: "end",
                                transform: "translateY(25px)"
                            }}>
                            {value}
                        </text>
                    </g>
                ))} */}
            </svg>
        </div>
    )
}  

function AxisX({ticks, transform}) {
    //console.log(ticks);
    return (
        <g
            key="xAxis"
            transform={transform}
        >
            {ticks.map(({ value, xOffset }) => (
                <g
                    key={value.toISOString()}
                    transform={`translate(${xOffset}, 0)`}
                >
                    <line
                        y2="6"
                        stroke="currentColor"
                    />
                    <text
                        key={value.toISOString()}
                        style={{
                            fontSize: "10px",
                            textAnchor: "middle",
                            transform: "translateY(20px)"
                        }}>
                        {new Intl.DateTimeFormat('fr-FR', dateFormatOptions).format(value)}
                    </text>
                </g>
            ))}
            {(ticks.length>0)?(
                <g>
                    <line 
                        x1={ticks[0].xOffset}
                        x2={ticks[ticks.length-1].xOffset}
                        stroke="currentColor"
                    />
                </g>
            ):<g />}
            
        </g>
    )
  }